"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import BaseModel
from gr4vy.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class GetPaymentServiceDefinitionRequestTypedDict(TypedDict):
    payment_service_definition_id: str


class GetPaymentServiceDefinitionRequest(BaseModel):
    payment_service_definition_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
